__kernel
void two_d_sor(   const int    N,
               __global float *A,
               __global float *B )
{
   // Get the work-items unique ID's
   int ir = get_global_id(0);   // row id
   int ic = get_global_id(1);   // column id

   // skip first row, last row, first column, and last column
   //  ir != 0 && ir != N-1 && ic != 0 && ic != N-1

   // The global id's have been offset by 1, so that helps
   // us skip over the first row and the first column.
   // And there are only n-2 work-items in each dimension,
   // so that helps us skip the last row and the last column.

   float n = A[(ir-1)*N + ic];
   float s = A[(ir+1)*N + ic];
   float e = A[ir*N + (ic+1)];
   float w = A[ir*N + (ic-1)];
   B[ir*N + ic] = (n + s + e + w) / 4.0;

// printf("ir = %d, ic = %d, n=%f, s=%f, e=%f, w=%f, %f\n", ir, ic, n,s,e,w, B[ir*N + ic]);
}